/*
 * PackageFilter.java
 * Created on 2011/10/13
 *
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

package jp.co.ntt.oss.heapstats.container;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import jp.co.ntt.oss.heapstats.gui.FilterEntriesModel;

/**
 * Holds the path to the excluded class.
 */
public class PackageFilter {
    /** Class Filter Map. Key is Filter name. Data is visible and class path. */
    private Map<String, List<String>> classFilter;

    /**
     * Create a PackageFilter.
     */
    public PackageFilter() {
        classFilter = new HashMap<String, List<String>>();
    }

    /**
     * Add a filter definition from the file read.
     *
     * @param addFilter Filter definition information to be added
     * @param filterEntriesModel FilterEntriesModel to draw the filter
     *        definition
     * @return Additional results filter definition. true is added.
     */
    public final boolean add(final Map<String, List<String>> addFilter,
            final FilterEntriesModel filterEntriesModel) {
        if(addFilter == null){
            return true;
        }
        Set<String> keys = addFilter.keySet();
        boolean duplicate = false;
        for (String key : keys) {
            List<String> data = classFilter.get(key);
            if (data != null) {
                duplicate = !duplicate;
                break;
            }
        }

        if (!duplicate) {
            Object[] rows = new Object[2];
            for (String key : keys) {
                rows[0] = Boolean.valueOf(addFilter.get(key).get(0));
                rows[1] = key;
                filterEntriesModel.addRow(rows);
            }

            classFilter.putAll(addFilter);

            return true;
        }
        return false;
    }

    /**
     * Clear filter definition.
     */
    public final void clear() {
        classFilter.clear();
    }

    /**
     * Returns the class path to be filtered.
     *
     * @param key Filter name
     * @return Returns the class path to be filtered.
     */
    public final List<String> get(final String key) {
        return classFilter.get(key);
    }
}
